@@ -1,6 +1,7 @@
-from os.path import dirname, basename, isfile, join
 import glob
-modules = glob.glob(join(dirname(__file__), "*.py"))
+from os.path import basename, dirname, isfile, join
+
+modules = glob.glob(join(dirname(__file__), '*.py'))
 __all__ = [basename(f)[:-3] for f in modules if isfile(f) and not f.endswith('__init__.py')]
 
 # import inspect
